@@ -20,11 +20,17 @@
 #define __WEATHER_PRIV_H_
 
 #include <time.h>
+#include <libintl.h>
 #include <libsoup/soup.h>
 
 #include "weather.h"
 #include "gweather-location.h"
 
+const char *gweather_gettext (const char *str) G_GNUC_FORMAT (1);
+#define _(str) (gweather_gettext (str))
+#define N_(str) (str)
+
+
 #define WEATHER_LOCATION_CODE_LEN 4
 
 WeatherLocation *gweather_location_to_weather_location (GWeatherLocation *gloc,
@@ -131,6 +137,7 @@ struct _WeatherInfo {
     DistanceUnit distance_unit;
 
     gboolean valid;
+    gboolean network_error;
     gboolean sunValid;
     WeatherLocation *location;
     WeatherUpdate update;
